# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .component_instance_layout_info import ComponentInstanceLayoutInfo
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class LayoutInfo(UniversalBaseModel):
    """
    Class to represent layout information of a circuit
    """

    instances: typing.Optional[typing.Dict[str, ComponentInstanceLayoutInfo]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
